{
****************************************************************
  Info               :  RogerColorGrid - Freeware
  Homepage           :  http://rogersoft.zzn.com
  Autor              :  Rogerio Olimpio Loureno de Oliveira
  E-mail             :  Rogerio.olimpio@rogersoft.zzn.com
  Delphi             :  Delphi 3
****************************************************************
 }

unit RogerColorGrid;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls;

type
    TDirection=(poHorizontal,poVertical);
type
  TRogerColorGrid = class(TCustomPanel)
  private
    { Private declarations }
      FFCor: TColor;
      FBCor: TColor;
      Fpos: TDirection;
      FHTMLfCor: ShortString;
      FHTMLbCor: ShortString;
      FOnColorChange: TNotifyEvent;
      constructor Create(AComponent: TComponent); override;
      procedure resize; override;
      procedure MontaGrid(Dir: TDirection);
      procedure SetFFCor(Cor: TColor);
      procedure SetFBCor(Cor: TColor);
      procedure ColorChange;
  protected
    { Protected declarations }
      Function WebColor(Cor:TColor): String;
  public
    { Public declarations }
  published
    { Published declarations }
    property ForeColor: TColor read FfCor write SetFFCor default clBlack;
    property BackColor: TColor read FbCor write SetFbCor default clWhite;
    property Position: TDirection read FPos write MontaGrid default poHorizontal;
    procedure ShapeClick(Sender: TObject; Button: TMouseButton;Shift: TShiftState; X, Y: Integer);
    property HTMLForeColor : shortString read FHTMLfCor;
    property HTMLBackColor : shortString read FHTMLbCor;
    property OnColorChange : TNotifyevent read FOnColorChange write FOnColorChange;
    property Enabled;
    property FullRepaint;
    property Color;
    property Ctl3D;
    property Locked;
    property ParentColor;
    property ParentCtl3D;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property TabOrder;
    property TabStop;
    property Visible;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDrag;
    property OnEnter;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
  end;

procedure Register;

implementation

const
  Color16: array [0..15] of TColor = (
        clBlack, clMaroon, clGreen, clOlive, clNavy, clPurple, clTeal, clGray,
    clSilver, clRed, clLime, clYellow, clBlue, clFuchsia, clAqua, clWhite);

Function TRogerColorGrid.WebColor(Cor:TColor): String;
var
     Temp : Integer;
     Temp2: String;
begin
     temp := ColorToRGB(Cor);
     Temp2 := IntToHex(temp,6);
     Result := '#'+Copy(Temp2,5,2)+Copy(Temp2,3,2)+Copy(Temp2,1,2);
end;

constructor TRogerColorGrid.Create(AComponent: TComponent);
begin
   inherited Create(AComponent);
   width:=240;
   height:=50;
   FfCor:=clBlack;
   fbcor:=clWhite;
   montagrid(poHorizontal);
end;

procedure TRogerColorGrid.SetFFCor(Cor: TColor);
begin
if ffcor<>cor then
begin
     Ffcor:=cor;
     TShape(FindComponent('SFcor')).brush.color:=ffcor;
     FHTMLfCor:= webcolor(ffcor);
     colorchange;
end;
end;

procedure TRogerColorGrid.SetFBCor(Cor: TColor);
begin
if fbcor<>cor then
begin
     Fbcor:=cor;
     TShape(FindComponent('SBcor')).brush.color:=fbcor;
     FHTMLbCor:= webcolor(fbcor);
     colorchange;
end;
end;

procedure TRogerColorGrid.MontaGrid(Dir: TDirection);
var
   x: TShape;
   y: Tbevel;
   a,b:integer;
   c1,c2, QCor: byte;
   d1,d2,t1,t2: integer;
   controle: TControl;
begin
   while ControlCount > 0 do
   begin
      controle:=Controls[0];
      removecontrol(controle);
      controle.destroy;
   end;
FPos:=Dir;
if Dir = poHorizontal then
begin
     c1:=1;
     c2:=7;
     d1:=60;
     d2:=4;
     t1:=240;
     t2:=50;
end
else
begin
     c1:=7;
     c2:=1;
     d1:=4;
     d2:=60;
     t1:=50;
     t2:=240;
end;

Width:=t1;
height:=t2;
QCor:=0;
for a:=0 to C1 do
    begin
         for b:=0 to C2 do
             begin
                  x:=TShape.Create(self);
                  x.height:=20;
                  x.width:=20;
                  x.left:=d1 + (b*22);
                  x.top:=d2 + (a*22);
                  x.Brush.color:=Color16[Qcor];
                  x.OnMouseDown:=ShapeClick;
                  InsertControl(x);
                  inc(QCor);
             end;
    end;
// ******* inclui quadros *****
try
y:=TBevel.Create(self);
y.height:=46;
y.width:=46;
y.left:=2;
y.top:=2;
insertControl(y);

x:=TShape.Create(self);
x.height:=30;
x.width:=30;
x.left:=15;
x.top:=15;
x.name:= 'SBCor';
x.Brush.color:=clWhite;
InsertControl(x);

x:=TShape.Create(self);
x.height:=30;
x.width:=30;
x.left:= 4;
x.top:= 4;
x.name:= 'SFCor';
x.Brush.color:=clBlack;
InsertControl(x);
except
end;
end;

procedure TRogerColorGrid.ShapeClick(Sender: TObject; Button: TMouseButton;
  Shift: TShiftState; X, Y: Integer);
begin
if ssleft in shift then
begin
   if ffcor<>TShape(sender).brush.color then
   begin
     ffcor:=TShape(sender).brush.color;
     TShape(FindComponent('SFcor')).brush.color:=ffcor;
     FHTMLfCor:= webcolor(ffcor);
     colorchange;
   end
end
else
begin
   if fbcor<>TShape(sender).brush.color then
   begin
     fbcor:=TShape(sender).brush.color;
     TShape(FindComponent('SBcor')).brush.color:=fbcor;
     FHTMLbCor:= webcolor(fbcor);
     colorchange;
   end
end;
end;

procedure TRogerColorGrid.resize;
begin
     MontaGrid(Fpos);
     inherited;
end;

procedure TRogerColorGrid.ColorChange;
begin
if assigned(FOnColorChange) then
   FOnColorChange(self);
end;

procedure Register;
begin
  RegisterComponents('MComps', [TRogerColorGrid]);
end;

end.
